; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| AI |-----------------------------------------------------------
[command]
name = "AI_1"
command = D, D, D, D, D, D, D, D
time = 0
[command]
name = "AI_2"
command = D, D, D, D, D, D, D, D
time = 0
[command]
name = "AI_3"
command = D, D, D, D, D, D, D, D
time = 0
[command]
name = "AI_4"
command = z, z, z, z, z, z, z, z
time = 0
[command]
name = "AI_5"
command = z, z, z, z, z, z, z, z
time = 0
[command]
name = "AI_6"
command = z, z, z, z, z, z, z, z
time = 0
[command]
name = "AI_7"
command = B, B, B, B, B, B, B, B
time = 0
[command]
name = "AI_8"
command = B, B, B, B, B, B, B, B
time = 0
[command]
name = "AI_9"
command = B, B, B, B, B, B, B, B
time = 0
[command]
name = "AI_10"
command = x, x, x, x, x, x, x, x
time = 0
[command]
name = "AI_11"
command = x, x, x, x, x, x, x, x
time = 0
[command]
name = "AI_12"
command = x, x, x, x, x, x, x, x
time = 0
[command]
name = "AI_13"
command = U, U, U, U, U, U, U, U
time = 0
[command]
name = "AI_14"
command = U, U, U, U, U, U, U, U
time = 0
[command]
name = "AI_15"
command = U, U, U, U, U, U, U, U
time = 0
[command]
name = "AI_16"
command = a, a, a, a, a, a, a, a
time = 0
[command]
name = "AI_17"
command = a, a, a, a, a, a, a, a
time = 0
[command]
name = "AI_18"
command = a, a, a, a, a, a, a, a
time = 0
[command]
name = "AI_19"
command = F, F, F, F, F, F, F, F
time = 0
[command]
name = "AI_20"
command = F, F, F, F, F, F, F, F
time = 0
[command]
name = "AI_21"
command = F, F, F, F, F, F, F, F
time = 0
[command]
name = "AI_22"
command = b, b, b, b, b, b, b, b
time = 0
[command]
name = "AI_23"
command = b, b, b, b, b, b, b, b
time = 0
[command]
name = "AI_24"
command = b, b, b, b, b, b, b, b
time = 0
[command]
name = "AI_25"
command = y, y, y, y, y, y, y, y
time = 0
[command]
name = "AI_26"
command = y, y, y, y, y, y, y, y
time = 0
[command]
name = "AI_27"
command = y, y, y, y, y, y, y, y
time = 0
[command]
name = "AI_28"
command = s, s, s, s, s, s, s, s
time = 0
[command]
name = "AI_29"
command = s, s, s, s, s, s, s, s
time = 0
[command]
name = "AI_30"
command = s, s, s, s, s, s, s, s
time = 0


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;AIpXe[giR}hH
;===========================================================================
;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
;X}bVEJt[EEbp[iQ[WxPj
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = ctrl && (var(30)=30)
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = p2statetype != L
trigger1 = p2bodydist X = [0,35];40
trigger1 = movehit
;trigger2 = hitdefattr = SC, NA, SA, HA
;trigger2 = stateno != [3050,3100)
;trigger2 = movecontact

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = ctrl && (var(30)=30)
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = p2statetype != L
trigger1 = p2bodydist X = [0,140];150
trigger1 = movehit
;trigger2 = hitdefattr = SC, NA, SA, HA
;trigger2 = stateno != [3000,3050)
;trigger2 = movecontact

;---------------------------------------------------------------------------
;Run Fwd
;_bV2
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
;trigger1 = var(6) = 1
trigger1 = p2bodydist X = [10,100]
trigger1 = p2statetype = A
;trigger2 = p2bodydist X = [101,300]

;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = null;ChangeState
value = 100
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
trigger1 = var(6) = 1
trigger1 = p2bodydist X = [20,100]
trigger1 = FrontEdgeDist >= 5 || p2movetype = H
;trigger2 = p2bodydist X = [101,300]

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
trigger1 = var(7) >= 3
trigger1 = p2bodydist X = [-50,50]

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype = S
triggerall = stateno != 100
;trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 5;3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
;trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
;trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H

;---------------------------------------------------------------------------
; 󒆃K[h
[State -1]
Type = ChangeState
Value = 140
triggerall = ctrl && (var(30)=30)
TriggerAll = StateType = A
Trigger1 = P2MoveType = A
Trigger1 = P2BodyDist X = [-50,150]

;---------------------------------------------------------------------------
; Ⴊ݃K[h
[State -1]
Type = ChangeState
Value = 150
triggerall = ctrl && (var(30)=30)
TriggerAll = StateType != A
Trigger1 = P2StateType = C
Trigger1 = P2MoveType  = A
Trigger1 = P2BodyDist X = [-50,150]

;---------------------------------------------------------------------------
; K[h
[State -1]
Type = ChangeState
Value = 130
triggerall = ctrl && (var(30)=30)
TriggerAll = StateType != A
Trigger1 = P2StateType != C
Trigger1 = P2MoveType = A
Trigger1 = P2BodyDist X = [-50,150]

;---------------------------------------------------------------------------
;Fast Kung Fu Blow (1/3 super bar)
[State -1, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = ctrl && (var(30)=30)
triggerall = power >= 330
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = IsHelper = 0
trigger1 = movehit
trigger1 = p2bodydist X = [-20,70]
trigger2 = IsHelper
trigger2 = movehit
trigger2 = p2bodydist X = [-20,70]
trigger2 = PrevStateNo != [1050,1120]
:trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -1, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = ctrl && (var(30)=30)
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = IsHelper = 0
trigger1 = movehit
trigger1 = p2bodydist X = [-20,70]
trigger2 = IsHelper
trigger2 = movehit
trigger2 = p2bodydist X = [-20,70]
trigger2 = PrevStateNo != [1050,1120]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = ctrl && (var(30)=30)
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = IsHelper = 0
trigger1 = movehit
trigger1 = p2bodydist X = [-20,70]
trigger2 = IsHelper
trigger2 = movehit
trigger2 = p2bodydist X = [-20,70]
trigger2 = PrevStateNo != [1050,1120]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Upper (1/3 super bar)
;Jt[EEbp[
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,35]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Upper
;Jt[EEbp[ij
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,40]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
;Jt[EEbp[ij
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,40]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = var(6) = 0
trigger1 = p2statetype != L
trigger1 = p2bodydist X = [0,38]
trigger2 = p2statetype = L
trigger2 = p2bodydist X = [0,40]

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,40]
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact && time > 5

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,45]
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact && time > 5

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,55]
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact && time > 5

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(8) = 0
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,40]
trigger1 = p2statetype != A
trigger2 = stateno = 200
trigger2 = time > 6
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(8) = 0
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,60]
trigger2 = (stateno = 200) && time > 5
trigger2 = movecontact
trigger3 = (stateno = 230) && time > 6
trigger3 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,50]
trigger2 = (stateno = 200) && time > 7
trigger2 = movecontact
trigger3 = (stateno = 230) && time > 9
trigger3 = movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = var(6) = 0
trigger1 = p2bodydist X = [0,60]
trigger2 = (stateno = 200) && time > 5
trigger2 = movecontact
trigger3 = (stateno = 230) && time > 6
trigger3 = movecontact

;---------------------------------------------------------------------------
;Jt[RiQ[WxP^Rjǌ
[State -1]
type = ChangeState
value = 1075
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype = A
triggerall = p2statetype = A
;trigger1 = p2bodydist X = [0,60]
trigger1 = (stateno = 1071) && time > 15
trigger2 = movecontact
trigger2 = stateno = 1071
;---------------------------------------------------------------------------
;Fast Kung Fu Knee (1/3 super bar)
;Jt[RiQ[WxP^Rj
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = p2statetype = A
trigger1 = p2bodydist X = [0,60]
;trigger1 = p2bodydist Y = [-20,-80]
trigger1 = movehit
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Jt[Rijijǌ
[State -1]
type = ChangeState
value = 1055
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype = A
triggerall = p2statetype = A
;trigger1 = p2bodydist X = [0,40]
trigger1 = (stateno = 1051) && time > 11
trigger2 = (stateno = 1061) && time > 11
trigger3 = (stateno = 1051) && movecontact
trigger4 = (stateno = 1061) && movecontact
;---------------------------------------------------------------------------
;Light Kung Fu Knee
;Jt[Rij
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype = A
triggerall = movehit
trigger1 = p2bodydist X = [0,60]
;trigger1 = p2bodydist Y = [-20,-80]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Knee
;Jt[Rij
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
triggerall = p2statetype = A
triggerall = movehit
trigger1 = p2bodydist X = [0,70]
;trigger1 = p2bodydist Y = [-20,-80]
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
;Jt[˂iQ[WxP^Rj
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,100]
trigger2 = p2bodydist X >= 100
trigger3 = var(6) = 1
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
trigger1 = p2statetype != L
trigger1 = p2bodydist X = [0,85]
;trigger2 = p2statetype = L
trigger2 = p2bodydist X = [20,100]
trigger3 = var(6) = 1
trigger3 = p2bodydist X < 20
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper = 0
triggerall = statetype != A
trigger1 = p2statetype != L
trigger1 = p2bodydist X = [0,100]
;trigger2 = p2statetype = L
;trigger2 = p2bodydist X >= 100
trigger2 = var(6) = 1
;trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Taunt
;
;[State -1, Taunt]
;type = ChangeState
;value = 195
;triggerall = command = "start"
;trigger1 = statetype != A
;trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = ctrl && (var(30)=30)
triggerall = statetype = A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,55]
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = ctrl && (var(30)=30)
triggerall = statetype = A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,50]
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = ctrl && (var(30)=30)
triggerall = statetype = A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,20]

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = ctrl && (var(30)=30)
triggerall = statetype = A
triggerall = p2statetype != L
trigger1 = p2bodydist X = [0,55]
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact





;===========================================================================
;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
;X}bVEJt[EEbp[iQ[WxPj
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = command = "SmashKFUpper"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = command = "TripleKFPalm"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
;Fast Kung Fu Knee (1/3 super bar)
;Jt[RiQ[WxP^Rj
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = command = "FF_ab"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Knee
;Jt[Rij
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = command = "FF_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Knee
;Jt[Rij
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = command = "FF_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
;Jt[˂iQ[WxP^Rj
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = command = "QCF_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = command = "QCF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = command = "QCF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Upper (1/3 super bar)
;Jt[EEbp[
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = command = "upper_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Upper
;Jt[EEbp[ij
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = command = "upper_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
;Jt[EEbp[ij
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = command = "upper_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Blow (1/3 super bar)
[State -1, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = command = "QCB_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -1, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = command = "QCB_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = command = "QCB_y"
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking


[State -1,2]
type       = Varset
triggerall = var(30) != 30
trigger1   = command = "AI_1"
trigger2   = command = "AI_2"
trigger3   = command = "AI_3"
trigger4   = command = "AI_4"
trigger5   = command = "AI_5"
trigger6   = command = "AI_6"
trigger7   = command = "AI_7"
trigger8   = command = "AI_8"
trigger9   = command = "AI_9"
trigger10  = command = "AI_10"
trigger11  = command = "AI_11"
trigger12  = command = "AI_12"
trigger13  = command = "AI_13"
trigger14  = command = "AI_14"
trigger15  = command = "AI_15"
trigger16  = command = "AI_16"
trigger17  = command = "AI_17"
trigger18  = command = "AI_18"
trigger19  = command = "AI_19"
trigger20  = command = "AI_20"
trigger21  = command = "AI_21"
trigger22  = command = "AI_22"
trigger23  = command = "AI_23"
trigger24  = command = "AI_24"
trigger25  = command = "AI_25"
trigger26  = command = "AI_26"
trigger27  = command = "AI_27"
trigger28  = command = "AI_28"
trigger29  = command = "AI_29"
trigger30  = command = "AI_30"
v          = 30
value      = 30

;AI I (jnA`hXCb`nee)
[State -1,2]
type=VarSet
trigger1   = P2life <= 0
v          = 30
value      = 0
[State -1,3]
type=VarSet
trigger1 = var(30) = 30
trigger1 = var(31) = 0
var(31) = 31
[State -1,4]
type=VarSet
trigger1 = var(30) = 0
trigger1 = var(31) = 31
trigger1 = RoundState = 2
var(30) = 30


;jp
;---------------------------------------------------------------------------
;Jt[EEbp[
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(2)
triggerall = power >= 330
triggerall = statetype != A
triggerall = p2statetype = A
trigger1 = p2bodydist X = [-5,35]
;---------------------------------------------------------------------------
;Jt[EEbp[ij
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(2)
triggerall = statetype != A
triggerall = p2statetype = A
trigger1 = p2bodydist X = [-5,40]
trigger1 = p2movetype = H
;---------------------------------------------------------------------------
;Jt[EEbp[ij
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(2)
triggerall = statetype != A
triggerall = p2statetype = A
trigger1 = p2bodydist X = [-5,40]
;---------------------------------------------------------------------------
;Jt[RiQ[WxP^Rjǌ
[State -1]
type = ChangeState
value = 1075
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper
triggerall = statetype = A
triggerall = p2statetype = A
trigger1 = (stateno = 1071) && time > 15
trigger2 = movecontact
trigger2 = stateno = 1071
;---------------------------------------------------------------------------
;Jt[RiQ[WxP^Rj
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper
triggerall = power >= 330
triggerall = statetype != A
triggerall = p2statetype = A
trigger1 = p2bodydist X = [0,60]
trigger1 = movehit
;---------------------------------------------------------------------------
;Jt[Rijijǌ
[State -1]
type = ChangeState
value = 1055
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper
triggerall = statetype = A
triggerall = p2statetype = A
;trigger1 = p2bodydist X = [0,40]
trigger1 = (stateno = 1051) && time > 11
trigger2 = (stateno = 1061) && time > 11
trigger3 = (stateno = 1051) && movecontact
trigger4 = (stateno = 1061) && movecontact
;---------------------------------------------------------------------------
;Jt[Rij
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper
triggerall = statetype != A
triggerall = p2statetype = A
triggerall = movehit
trigger1 = p2bodydist X = [0,60]
;---------------------------------------------------------------------------
;Jt[Rij
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper
triggerall = statetype != A
triggerall = p2statetype = A
triggerall = movehit
trigger1 = p2bodydist X = [0,70]
;---------------------------------------------------------------------------
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper;(2)
triggerall = statetype = S
triggerall = stateno != 100
trigger1 = p2bodydist X = [-5,5]
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
;---------------------------------------------------------------------------
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(2)
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = 1
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact && time > 5
;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(2)
triggerall = statetype != A
trigger1 = p2statetype = L


;Ojp
;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(3)
triggerall = statetype != A
trigger1 = 1
trigger2 = p2statetype = L
;---------------------------------------------------------------------------
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = ctrl && (var(30)=30)
triggerall = IsHelper(3)
triggerall = statetype != A
triggerall = p2statetype = A
trigger1 = 1
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact && time > 5
